@@ -148,7 +148,7 @@ def models_to_src(models: typing.Iterable[ModelClass]) -> typing.Iterable[str]:
             res.append(f"{INDENT*3}ignore_props: list[str] = None,")
             res.extend(fields_arg_list)
             res.extend(relationships_arg_list)
-            res.append(f"{INDENT}): ...")
+            res.append(f"{INDENT}) -> {model.name}: ...")
             res.append("")
         for func in model.functions:
             res.extend([f"{INDENT}{line}" for line in method_to_src(func)])
